@@ -6,10 +6,19 @@ style.appendChild(
     .local-media-controls,
     #localVideoContainer,
     button.stripe--collapse,
-    .grid-navigation {
+    .grid-navigation,
+    .app-talk .vue-tooltip,
+    .toastify,
+    #app-navigation-vue {
         display: none;
     }
 
+    #videos {
+        height: 100% !important;
+        top: 0 !important;
+        padding: 8px !important;
+    }
+
     .stripe-wrapper {
         width: 100% !important;
     }
